/**
 * @file Fichier de configuration Knex. Il spécifie la base de donnée à laquelle se connecter, son adresse, le nom 
 * d'un utilisateur sur le serveur qui a les droits appropriés, et son mot de passe.
 * 
 * Le fichier précise également où stocker les fichiers de migrations Knex ainsi que les _seeds_.
 * 
 * Plus précisément, ce fichier sert de fichier de configuration à la commande `knex` (en lignes de commande)
 * et c'est knex_router.js qui donne la configuration de knex.js à proprement parler (i.e. les méthodes knex.insert(...) dans le code javascript)
 * @author manifold
 */
require('dotenv').config();
const path = require('path');

const knexConfig = {
    migrations: {
        tableName: 'knex_migrations',
        directory: path.resolve('./migrations_v3' /*'./db/migrations'*/)
    },
    seeds: {
        directory: path.resolve('./seeds_v3' /*'./db/seeds'*/)
    }
};

module.exports = {
    development: {
        client: 'pg',
        connection: {
            host: 'localhost',
            user: process.env.DB_USER || 'sigma',
            password: process.env.DB_PASSWD || 'sigmapw',
            database: 'sigma_dev',
            charset: 'utf8'
        },
        ...knexConfig
    },
    staging: {
        client: 'pg',
        connection: {
            host: process.env.DB_HOST || '129.201.104.10',
            user: process.env.DB_USER || 'sigma',
            password: process.env.DB_PASSWD || 'password',
            database: 'sigma_staging',
            charset: 'utf8'
        },
        ...knexConfig
    }
};
